-- Table: public.employees

-- DROP TABLE public.employees;

CREATE TABLE public.employees
(
    id integer NOT NULL,
    name_and_title character varying(200) COLLATE pg_catalog."default" NOT NULL,
    relation_name character varying(500) COLLATE pg_catalog."default",
    relation_position character varying(500) COLLATE pg_catalog."default",
    CONSTRAINT employees_pkey PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.employees
    OWNER to mariannarachelova;

-- Table: public.employee_web

-- DROP TABLE public.employee_web;

CREATE TABLE public.employee_web
(
    id integer NOT NULL,
    web character varying(500) COLLATE pg_catalog."default",
    employee_id integer,
    CONSTRAINT employee_web_pkey PRIMARY KEY (id),
    CONSTRAINT employee_id5 FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.employee_web
    OWNER to mariannarachelova;

-- Index: fki_employee_id5

-- DROP INDEX public.fki_employee_id5;

CREATE INDEX fki_employee_id5
    ON public.employee_web USING btree
    (employee_id)
    TABLESPACE pg_default;

-- Table: public.employee_voip

-- DROP TABLE public.employee_voip;

CREATE TABLE public.employee_voip
(
    id integer NOT NULL,
    voip integer,
    employee_id integer,
    CONSTRAINT employee_voip_pkey PRIMARY KEY (id),
    CONSTRAINT employee_id4 FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.employee_voip
    OWNER to mariannarachelova;

-- Index: fki_employee_id4

-- DROP INDEX public.fki_employee_id4;

CREATE INDEX fki_employee_id4
    ON public.employee_voip USING btree
    (employee_id)
    TABLESPACE pg_default;

-- Table: public.employee_publications

-- DROP TABLE public.employee_publications;

CREATE TABLE public.employee_publications
(
    id integer NOT NULL,
    publications_link character varying(200) COLLATE pg_catalog."default",
    employee_id integer,
    CONSTRAINT employee_publications_pkey PRIMARY KEY (id),
    CONSTRAINT employee_id FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT employee_id2 FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.employee_publications
    OWNER to mariannarachelova;

-- Index: fki_em_id

-- DROP INDEX public.fki_em_id;

CREATE INDEX fki_em_id
    ON public.employee_publications USING btree
    (employee_id)
    TABLESPACE pg_default;

-- Table: public.employee_places

-- DROP TABLE public.employee_places;

CREATE TABLE public.employee_places
(
    id integer NOT NULL,
    place character varying(200) COLLATE pg_catalog."default",
    employee_id integer,
    CONSTRAINT employee_places_pkey PRIMARY KEY (id),
    CONSTRAINT employee_id FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT employee_id1 FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.employee_places
    OWNER to mariannarachelova;

-- Index: fki_employee_id1

-- DROP INDEX public.fki_employee_id1;

CREATE INDEX fki_employee_id1
    ON public.employee_places USING btree
    (employee_id)
    TABLESPACE pg_default;

-- Table: public.employee_phone_number

-- DROP TABLE public.employee_phone_number;

CREATE TABLE public.employee_phone_number
(
    id integer NOT NULL,
    phone_number character varying(200) COLLATE pg_catalog."default",
    employee_id integer,
    CONSTRAINT employee_phone_number_pkey PRIMARY KEY (id),
    CONSTRAINT employee_id FOREIGN KEY (employee_id)
        REFERENCES public.employees (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.employee_phone_number
    OWNER to mariannarachelova;

-- Index: fki_employee_id

-- DROP INDEX public.fki_employee_id;

CREATE INDEX fki_employee_id
    ON public.employee_phone_number USING btree
    (employee_id)
    TABLESPACE pg_default;


-- Table: public.canteens

-- DROP TABLE public.canteens;

CREATE TABLE public.canteens
(
    id integer NOT NULL,
    name character varying(200) COLLATE pg_catalog."default",
    CONSTRAINT canteens_pkey PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.canteens
    OWNER to mariannarachelova;

-- Table: public.canteen_daily_offers

-- DROP TABLE public.canteen_daily_offers;

CREATE TABLE public.canteen_daily_offers
(
    id integer NOT NULL,
    day_and_date character varying(200) COLLATE pg_catalog."default",
    dish_name character varying(500) COLLATE pg_catalog."default",
    canteen_id integer,
    CONSTRAINT canteen_daily_offers_pkey PRIMARY KEY (id),
    CONSTRAINT canteen_id FOREIGN KEY (canteen_id)
        REFERENCES public.canteens (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.canteen_daily_offers
    OWNER to mariannarachelova;

-- Index: fki_canteen_id

-- DROP INDEX public.fki_canteen_id;

CREATE INDEX fki_canteen_id
    ON public.canteen_daily_offers USING btree
    (canteen_id)
    TABLESPACE pg_default;

-- Table: public.faculty

-- DROP TABLE public.faculty;

CREATE TABLE public.faculty
(
    id integer NOT NULL,
    map character varying(10000000) COLLATE pg_catalog."default",
    CONSTRAINT faculty_pkey PRIMARY KEY (id)
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE public.faculty
    OWNER to mariannarachelova;
